@@ -1,10 +1,10 @@
 #' @title Minnesota Radon Dataset 
 #' 
+#' @name radon
 #' @description Radon levels in 919 homes from 85 Minnesota counties
 #' @usage data(radon)
 #' @format A numeric matrix 
 #' @keywords datasets
 #' @source \url{http://www.stat.columbia.edu/~gelman/arm/software/}
-"radon"
-#> [1] "radon"
+NULL
 
